/***************************************************************************//**
 *   @file   ADIS16227.c
 *   @brief  Header file of ADIS16227 Driver.
 *   @author DBogdan (dragos.bogdan@analog.com)
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 491
*******************************************************************************/
#ifndef _ADIS16227_H_
#define _ADIS16227_H_

/******************************************************************************/
/* ADIS16227                                                                  */
/******************************************************************************/

/* ADIS16227 GPIO */
#define ADIS16227_RESET_OUT     GPIO1_PIN_OUT
#define ADIS16227_RESET_LOW     GPIO1_LOW
#define ADIS16227_RESET_HIGH    GPIO1_HIGH

/* ADIS16227 Register Map */
#define ADIS16227_FLASH_CNT     0x00  // Status, flash memory write count
#define ADIS16227_X_NULL        0x02  // X-axis accelerometer offset correction
#define ADIS16227_Y_NULL        0x04  // Y-axis accelerometer offset correction
#define ADIS16227_Z_NULL        0x06  // Z-axis accelerometer offset correction
#define ADIS16227_REC_FLSH_CNT  0x08  // Record flash write/erase counter
#define ADIS16227_SUPPLY_OUT    0x0A  // Output, power supply during capture
#define ADIS16227_TEMP_OUT      0x0C  // Output, temperature during capture
#define ADIS16227_FFT_AVG       0x0E  // Control, number of FFT records to average
#define ADIS16227_BUF_PNTR      0x10  // Control, buffer address pointer
#define ADIS16227_REC_PNTR      0x12  // Control, record address pointer
#define ADIS16227_X_BUF         0x14  // Output, buffer for x-axis acceleration data
#define ADIS16227_Y_BUF         0x16  // Output, buffer for y-axis acceleration data
#define ADIS16227_Z_BUF         0x18  // Output, buffer for z-axis acceleration data
#define ADIS16227_REC_CNTR      0x1A  // Control, record counter
#define ADIS16227_REC_CTRL      0x1C  // Control, record control register
#define ADIS16227_REC_PRD       0x1E  // Control, record period (automatic mode)
#define ADIS16227_ALM_F_LOW     0x20  // Alarm, spectral band lower frequency limit
#define ADIS16227_ALM_F_HIGH    0x22  // Alarm, spectral band upper frequency limit
#define ADIS16227_ALM_X_MAG1    0x24  // Alarm, x-axis, Alarm 1 level
#define ADIS16227_ALM_Y_MAG1    0x26  // Alarm, y-axis, Alarm 1 level
#define ADIS16227_ALM_Z_MAG1    0x28  // Alarm, z-axis, Alarm 1 level
#define ADIS16227_ALM_X_MAG2    0x2A  // Alarm, x-axis, Alarm 2 level
#define ADIS16227_ALM_Y_MAG2    0x2C  // Alarm, y-axis, Alarm 2 level
#define ADIS16227_ALM_Z_MAG2    0x2E  // Alarm, z-axis, Alarm 2 level
#define ADIS16227_ALM_PNTR      0x30  // Alarm, spectral alarm band pointer
#define ADIS16227_ALM_S_MAG     0x32  // Alarm, system alarm level
#define ADIS16227_ALM_CTRL      0x34  // Alarm, configuration
#define ADIS16227_DIO_CTRL      0x36  // Control, functional I/O configuration
#define ADIS16227_GPIO_CTRL     0x38  // Control, general-purpose I/O
#define ADIS16227_DIAG_STAT     0x3C  // Status, system error flags
#define ADIS16227_GLOB_CMD      0x3E  // Control, global command register
#define ADIS16227_ALM_X_STAT    0x40  // Alarm, x-axis, status for spectral alarm bands
#define ADIS16227_ALM_Y_STAT    0x42  // Alarm, y-axis, status for spectral alarm bands
#define ADIS16227_ALM_Z_STAT    0x44  // Alarm, z-axis, status for spectral alarm bands
#define ADIS16227_ALM_X_PEAK    0x46  // Alarm, x-axis, peak value (most severe alarm)
#define ADIS16227_ALM_Y_PEAK    0x48  // Alarm, y-axis, peak value (most severe alarm)
#define ADIS16227_ALM_Z_PEAK    0x4A  // Alarm, z-axis, peak value (most severe alarm)
#define ADIS16227_TIME_STAMP_L  0x4C  // Record time stamp, lower word
#define ADIS16227_TIME_STAMP_H  0x4E  // Record time stamp, upper word
#define ADIS16227_LOT_ID1       0x52  // Lot identification code
#define ADIS16227_LOT_ID2       0x54  // Lot identification code
#define ADIS16227_PROD_ID       0x56  // Product identifier; convert to decimal = 16,227
#define ADIS16227_SERIAL_NUM    0x58  // Serial number
#define ADIS16227_ALM_X_FREQ    0x70  // Alarm, x-axis, frequency of most severe alarm
#define ADIS16227_ALM_Y_FREQ    0x72  // Alarm, y-axis, frequency of most severe alarm
#define ADIS16227_ALM_Z_FREQ    0x74  // Alarm, z-axis, frequency of most severe alarm
#define ADIS16227_REC_INFO      0x76  // Record settings

/* ADIS16227 Default Product ID */
#define ADIS16227_DEFAULT_PID   0x3F63  // Default Product ID.

/* ADIS16227_REC_CTRL bits */
#define ADIS16227_REC_CTRL_WINDOW(x)    (((x) & 0x3) << 12)
#define ADIS16227_REC_CTRL_SR(x)        (((x) & 0xF) << 8)
#define ADIS16227_REC_CTRL_PWR_DWN_REC  (1 << 7)
#define ADIS16227_REC_CTRL_RANGE(x)     (((x) & 0x3) << 4)
#define ADIS16227_REC_CTRL_STORAGE(x)   (((x) & 0x3) << 2)
#define ADIS16227_REC_CTRL_MODE(x)      ((x) & 0x3)

/* ADIS16227_REC_CTRL_WINDOW(x) options */
#define ADIS16227_RECTANGULAR           0
#define ADIS16227_HANNING               1
#define ADIS16227_FLAT_TOP              2

/* ADIS16227_REC_CTRL_SR(x) options */
#define ADIS16227_FS                    1
#define ADIS16227_FS_DIV_8              2
#define ADIS16227_FS_DIV_64             4
#define ADIS16227_FS_DIV_512            8

/* ADIS16227_REC_CTRL_RANGE(x) options */
#define ADIS16227_RANGE_0_1G            0
#define ADIS16227_RANGE_0_5G            1
#define ADIS16227_RANGE_0_20G           2
#define ADIS16227_RANGE_0_70G           3

/* ADIS16227_REC_CTRL_STORAGE(x) options */
#define ADIS16227_STORAGE_NONE          0
#define ADIS16227_STORAGE_ALARM         1
#define ADIS16227_STORAGE_ALL           2

/* ADIS16227_REC_CTRL_MODE(x) options */
#define ADIS16227_MANUAL                0
#define ADIS16227_AUTOMATIC             1
#define ADIS16227_MANUAL_TIME           2

/* ADIS16227_DIAG_STAT bits */
#define ADIS16227_DIAG_STAT_Z_ALARM2        (1<<13)
#define ADIS16227_DIAG_STAT_Y_ALARM2        (1<<12)
#define ADIS16227_DIAG_STAT_X_ALARM2        (1<<11)
#define ADIS16227_DIAG_STAT_Z_ALARM1        (1<<10)
#define ADIS16227_DIAG_STAT_Y_ALARM1        (1<<9)
#define ADIS16227_DIAG_STAT_X_ALARM1        (1<<8)
#define ADIS16227_DIAG_STAT_DATA_RDY        (1<<7)
#define ADIS16227_DIAG_STAT_FLASH_CHK       (1<<6)
#define ADIS16227_DIAG_STAT_SELF_TEST       (1<<5)
#define ADIS16227_DIAG_STAT_REC_ESC         (1<<4)
#define ADIS16227_DIAG_STAT_SPI_FAIL        (1<<3)
#define ADIS16227_DIAG_STAT_FLASH_UPT       (1<<2)
#define ADIS16227_DIAG_STAT_POWER_HIGH      (1<<1)
#define ADIS16227_DIAG_STAT_POWER_LOW       (1<<0)

/* ADIS16227_GLOB_CMD bits */
#define ADIS16227_GLOB_CMD_CLR_X_NULL       (1 << 15)
#define ADIS16227_GLOB_CMD_SAB_INFO         (1 << 14)
#define ADIS16227_GLOB_CMD_RSTR_REC_DATA    (1 << 13)
#define ADIS16227_GLOB_CMD_SAB_REG_TO_FLASH (1 << 12)
#define ADIS16227_GLOB_CMD_REC_START_STOP   (1 << 11)
#define ADIS16227_GLOB_CMD_BUFF_PNTR_0      (1 << 10)
#define ADIS16227_GLOB_CMD_CLR_SAB_REG      (1 << 9)
#define ADIS16227_GLOB_CMD_CLR_RECORDS      (1 << 8)
#define ADIS16227_GLOB_CMD_SW_RESET         (1 << 7)
#define ADIS16227_GLOB_CMD_REG_TO_FLASH     (1 << 8)
#define ADIS16227_GLOB_CMD_FLASH_TEST       (1 << 5)
#define ADIS16227_GLOB_CMD_CLR_DIAG_STAT    (1 << 4)
#define ADIS16227_GLOB_CMD_RSTR_FACT_SET    (1 << 3)
#define ADIS16227_GLOB_CMD_SELF_TEST        (1 << 2)
#define ADIS16227_GLOB_CMD_PWR_DOWN         (1 << 1)
#define ADIS16227_GLOB_CMD_AUTONULL         (1 << 0)

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/

/* Reads the value of a register. */
unsigned short ADIS16227_GetRegister16Value(unsigned char registerAddress);

/* Writes 1 byte into a register. */
void ADIS16227_SetRegister8Value(unsigned char registerAddress,
                                 unsigned char registerValue);

/* Writes 2 bytes into a register. */
void ADIS16227_SetRegister16Value(unsigned char registerAddress,
                                  unsigned short registerValue);

/* Initializes the SPI and checks if the ADIS16227 part is present. */
unsigned char ADIS16227_Init(void);

/* Configures the ADIS16227_REC_CTRL register. */
void ADIS16227_ConfigCapture(unsigned char window,
                             unsigned char sampleRate,
                             unsigned char pwrDwn,
                             unsigned char range,
                             unsigned char mode);

/* Reads the value of the "Data ready/busy" bit (DIAG_STAT register). */
unsigned char ADIS16227_DataReady(void);

/* Initiates a manual data capture and wait until the process is finished. */
void ADIS16227_Capture(void);

/* Reads "samplesNumber" samples from each axis's buffer. */
void ADIS16227_GetBuffers(unsigned short* x,
                          unsigned short* y,
                          unsigned short* z,
                          unsigned short samplesNumber);

/* Reads the power supply voltage and returns the data in mV. */
unsigned short ADIS16227_GetPowerSupplyInfo(void);

/* Reads the internal temperature and returns the data in degrees Celsius. */
char ADIS16227_GetTemperatureInfo(void);

#endif	// _ADIS16227_H_
