/***************************************************************************//**
 *   @file   Main.c
 *   @brief  Implementation of the program's main function.
 *   @author DBogdan (dragos.bogdan@analog.com)
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 491
*******************************************************************************/

/******************************************************************************/
/* Include Files                                                              */
/******************************************************************************/
#include "YRDKRL78G13.h"
#include "ST7579.h"
#include "ADIS16227.h"

/******************************************************************************/
/* Option Bytes                                                               */
/******************************************************************************/
#pragma location = "OPTBYTE"
__root const uint8_t opbyte0 = 0x00U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte1 = 0xFFU;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte2 = 0xE8U;
#pragma location = "OPTBYTE"
__root const uint8_t opbyte3 = 0x04U;

/******************************************************************************/
/* Security ID                                                                */
/******************************************************************************/
#pragma location = "SECUID"
__root const uint8_t secuid[10] = 
    {0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U, 0x00U};

/******************************************************************************/
/* Variables Declarations                                                     */
/******************************************************************************/
const unsigned char adiLogo [2 * 19] =
	{ 0xFF, 0xFF, 0xFF, 0x03, 0x03, 0x03, 0x07, 0x07,
	  0x0F, 0x0F, 0x1F, 0x1F, 0x3F, 0x3F, 0x7F, 0x7F,
	  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xC0,
	  0xC0, 0xE0, 0xE0, 0xF0, 0xF0, 0xF8, 0xF8, 0xFC,
	  0xFC, 0xFE, 0xFE, 0xFF, 0xFF, 0xFF };             // ADI Logo.
unsigned short  xData[10]   = {0, };
unsigned short  yData[10]   = {0, };
unsigned short  zData[10]   = {0, };
unsigned short  voltage     = 0;
unsigned char   temperature = 0;

/***************************************************************************//**
 * @brief Creates a delay of miliseconds.
 *
 * @param mSeconds - time in miliseconds.
 *
 * @return None.
*******************************************************************************/
void DelayMs(unsigned long mSeconds)
{
    unsigned long time = 0;
    
    R_TAU0_Channel0_Start();
    while(time < mSeconds)
    {
        if(TMIF00 == 1)
        {
            time++;
            TMIF00 = 0;
        }
    }
    R_TAU0_Channel0_Stop();
}

/***************************************************************************//**
 * @brief Main function.
 *
 * @return None.
*******************************************************************************/
void main(void)
{
    YRDKRL78G13_Init();
	ST7579_Init();
    ST7579_Image(2,0,adiLogo,19,16);
    ST7579_String(2,21,"ANALOG");
    ST7579_String(3,21,"DEVICES");
    ST7579_String(4,0,"wiki.analog.com");
    DelayMs(2000);
    ST7579_Clear();
    ST7579_Image(0,0,adiLogo,19,16);	
    ST7579_String(0,22,"ST7579 OK");
    if(ADIS16227_Init())
    {
        ST7579_String(1,22,"ADIS16227 OK");
    }
    else
    {
        ST7579_String(2,22,"ADIS16227 Er");
    }
    /* Offset Correction. */
    ADIS16227_SetRegister8Value(ADIS16227_GLOB_CMD,
                                ADIS16227_GLOB_CMD_AUTONULL);
    DelayMs(681);
    /* Configure the ADIS16227_REC_CTRL register. */
    ADIS16227_ConfigCapture(ADIS16227_HANNING,
                            ADIS16227_FS,
                            0,
                            ADIS16227_RANGE_0_5G,
                            ADIS16227_MANUAL_TIME);
    /* Initiate a manual data capture. */
    ADIS16227_Capture();
    /* Read and display the internal temperature. */
    ST7579_String(3,1,"Temp.(C):");
    temperature = ADIS16227_GetTemperatureInfo();
    ST7579_Number(3, 80, temperature, 2);
    /* Read and display the power supply voltage. */
    ST7579_String(4,1,"Volt.(mV):");
    voltage = ADIS16227_GetPowerSupplyInfo();
    ST7579_Number(4, 80, voltage, 4);
    /* Read 10 samples from each axis's buffer. */
    ADIS16227_GetBuffers(xData, yData, zData, 10);
    /* Display xData[0], yData[0] and zData[0]. */
    ST7579_String(5,1,"xBuf[0]:");
    ST7579_Number(5, 80, xData[0], 3);
    ST7579_String(6,1,"yBuf[0]:");
    ST7579_Number(6, 80, yData[0], 3);
    ST7579_String(7,1,"zBuf[0]:");
    ST7579_Number(7, 80, zData[0], 3);

    while (1)
    {
    }
}
